# Colibris Framework


[![Actions Status](https://github.com/colibris-framework/colibris/workflows/Main/badge.svg)](https://github.com/colibris-framework/colibris/actions)
[![Documentation Status](https://readthedocs.org/projects/colibris/badge/?version=latest)](https://colibris.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/colibris.svg?color=blue)](https://pypi.org/project/colibris/)


A lightweight framework for RESTful microservices.

## Documentation
Full documentation is available at [https://colibris.readthedocs.io/](https://colibris.readthedocs.io/).
